# Changelog

## 0.0.1 (2025-10-20)

Full Changelog: [v0.0.1...v0.0.1](https://github.com/indicesio/indices-python/compare/v0.0.1...v0.0.1)

### Features

* **api:** manual updates ([bd1ba01](https://github.com/indicesio/indices-python/commit/bd1ba01702edb85b98309a8f4b8b626c7a4f34f1))


### Chores

* update SDK settings ([29395f4](https://github.com/indicesio/indices-python/commit/29395f42da941577e78d2e18f310dfdfac11e044))
* update SDK settings ([7e79028](https://github.com/indicesio/indices-python/commit/7e79028fed7be3b520ff233352d28d0b9518d2ab))
